@@ -15,5 +15,5 @@ from tensorfn.util import (
     get_logger,
     create_small_table,
 )
-from tensorfn.checker import Checker
+from tensorfn.checker import Checker, Checker2
 from tensorfn.trainer import Trainer
