@@ -7,9 +7,10 @@ import json
 import uuid
 
 import torch
-from torch.distributed.elastic.multiprocessing import Std
-from torch.distributed.elastic.rendezvous.utils import _parse_rendezvous_config
-from torch.distributed.launcher.api import LaunchConfig
+
+# from torch.distributed.elastic.multiprocessing import Std
+# from torch.distributed.elastic.rendezvous.utils import _parse_rendezvous_config
+# from torch.distributed.launcher.api import LaunchConfig
 from pyhocon import ConfigFactory, ConfigTree
 
 try:
@@ -17,7 +18,7 @@ try:
 except ImportError:
     _jsonnet = None
 
-from tensorfn.distributed import is_primary
+# from tensorfn.distributed import is_primary
 
 
 def read_config(config_file, overrides=(), strict=False):
