@@ -1,8 +1,9 @@
-from torch.utils import cpp_extension as cpp_ext
-
-
 class LazyExtension:
     def __init__(self, name, sources):
+        from torch.utils import cpp_extension
+
+        self.cpp_ext = cpp_extension
+
         self.name = name
         self.sources = sources
         self.loaded = False
@@ -10,6 +11,6 @@ class LazyExtension:
 
     def get(self):
         if self.extension is None:
-            self.extension = cpp_ext.load(self.name, sources=self.sources)
+            self.extension = self.cpp_ext.load(self.name, sources=self.sources)
 
         return self.extension
